#

#   Seurat3Int_To_cHX_Step3.R
#   /DS/NF/Seurat3IntVignette
#
#    
#   May 10, 2020
#
#   This code was written with Seurat version 3.1.3
#   on a MacBook running R 3.6.1
#
#  This program creates the Clustering-exp.cHX.txt
#  file from exp.cHX.txt, groups.cHX.txt and 
#  integ_so_clusterMarkers.txt files.
#
#  The function For_cHX_Step3f, sourced from a
#  separate file, is called to do most of the work.
#
#  This is the most complex step in the file
#  preparation process.  There is some code
#  at the end of the program to perform some 
#  consistency checks. Visual inspection
#  of the Clustering-exp file is also recommended.
#  
#  ** Code for user to adjust is preceded by # ////
#
#  = = = = = = = =  Setup = = = = = = = = 

# //// Provide paths for input, output and Step3f function
in1DataPath="/DS/NF/Seurat3IntVignette/"
outDataPath=in1DataPath
functionPath="/DS/Misc/Seurat_To_cellHarmony/May2020/"

#  = = = = BRING IN THE 3 FILES = = = = =

# //// Provide filenames for expression, groups and markers
f=paste(in1DataPath,"exp.cHX.txt",sep="")
message(" ** Reading ",f," ** ")
exp_file=read.table(file=f,sep="\t",header = T,
                    stringsAsFactors = F)

f=paste(in1DataPath,"groups.cHX.txt",sep="")
message(" ** Reading ",f," ** ")
groups_file=read.table(file=f,sep="\t",header = T,
                    stringsAsFactors = F)

f=paste(in1DataPath,"integ_so_clusterMarkers.txt",sep="")
message(" ** Reading ",f," **",sep="")
markers_file=read.table(file=f,sep="\t",header=T,stringsAsFactors=F)

#  checks
colnames(exp_file)[1]=="UID"
identical(colnames(exp_file)[2:ncol(exp_file)],
                 groups_file$cell_id)

#  = = = = =  Make the Clustering-exp FILE = = = 
#  by calling the following function

f=paste(functionPath,"For_cHX_Step3f.R",sep="")
source(f)

# ////  Change MaxMarkers (per cluster) here 
# ** Changing MoreThan1Cluster to "ok" not recommended
For_cHX_Step3f(exp_file=exp_file,
              groups_file=groups_file,
              markers_file=markers_file,
              MaxMarkers=50,
              MoreThan1Cluster="only1",
              OutputPath=outDataPath)
  
# = = = SOME CHECKING OF Clustering-exp FILE = = 

f=paste(outDataPath,"Clustering-exp.cHX.txt",sep="")
#  need to read in with header=F to avoid variable type problems
#  as a result everything read in as character variables
hm.fmt=read.table(file=f,sep="\t",header=F,check.names = F,
                  stringsAsFactors = F)
# make a df with cellname and cluster info from hm.fmt
hm.df=data.frame(t(hm.fmt[1,3:ncol(hm.fmt)]),
                 t(hm.fmt[2,3:ncol(hm.fmt)]),
                 stringsAsFactors = F)
names(hm.df)=c("celln","hm.clust")

#  Set up to compare to info in input files
gf.df=data.frame(celln=groups_file$cell_id,
                 gf.clust=as.character(groups_file$cluster_number),
                 stringsAsFactors = F)

check.df=merge(x=gf.df,y=hm.df,
               by="celln",all=T)
#  following should be TRUE
nrow(gf.df)==nrow(hm.df) 
nrow(check.df)==nrow(hm.df)
identical(check.df$gf.clust, check.df$hm.clust)
#   all 3 checks satisfied

####    END OF PROGRAM ######


quit()
